package application

import (
	"fmt"
	"net/http"
	"os"
	"path"
	"sirlab.de/go/knyt/user"
)

func (app *Application) RemoveQuote(usr *user.User, w http.ResponseWriter, r *http.Request) {
	gameRef := r.URL.Query().Get("g")
	gm, err := app.GetGameById(gameRef)
	if err != nil {
		w.WriteHeader(http.StatusNotFound)
		fmt.Fprintf(w, "game not found")
		return
	}

	if usr.GetGameId() != gameRef || !usr.IsGamemaster() {
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	}

	quoteId := r.URL.Query().Get("id")
	if quote, err := gm.RemoveQuote(usr.GetId(), quoteId); err != nil {
		fmt.Printf("%s\n", err)
		w.WriteHeader(http.StatusForbidden)
		fmt.Fprintf(w, "forbidden")
		return
	} else {
		gameDirName := path.Join(app.config.DataDir, "games", gm.GetId())
		quoteFileNameShort := quote.GetId() + ".json"
		quoteFileName := path.Join(gameDirName, "quotes", quoteFileNameShort)

		if err := os.Remove(quoteFileName); err != nil {
			fmt.Printf("%s\n", err)
			w.WriteHeader(http.StatusForbidden)
			fmt.Fprintf(w, "forbidden")
			return
		}

		fmt.Fprintf(w, "ok")
	}
}
